#! /bin/sh
#------------------------------------------------------------------------------
# /var/install/config.d/backup-zip-update.sh
#
# --- Backup-ZIP 1.5.0 for Eis/Fair Server ---
#
# Copyright (c) 2005      Hans-Peter Seiler <hanspeterseiler(at)web.de>
#               2015-2021 Marcus Roeckrath <marcus.roeckrath(at)gmx.de>
#
# Creation:     15.09.2005  hs
# Last Update:  28.01.2021  mr
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#------------------------------------------------------------------------------

#set -x

. /var/install/include/eislib
prog=backup-zip

if [ -f "/etc/config.d/$prog-sich" ] ; then
    mv /etc/config.d/$prog-sich /etc/config.d/$prog
elif [ ! -f "/etc/config.d/$prog" ] ; then
    cp -a /etc/default.d/$prog /etc/config.d/$prog
    exit
fi

# Update Configuration if found

mecho --warn "Updating configuration file; this could take some time. Please be patient."

grep "Backup-ZIP 1.0.11" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
    # change version data
    sed "s#Backup-ZIP 1.[0-9].[0-9]\{1,\}#Backup-ZIP 1.0.12#" "/etc/config.d/$prog" >/tmp/$prog-$$
    mv /tmp/$prog-$$ /etc/config.d/$prog

    sed "s#Update:  [0-9]*.[0-9]*.[0-9]*#Update:  13.10.2007#" "/etc/config.d/$prog" >/tmp/$prog-$$
    mv /tmp/$prog-$$ /etc/config.d/$prog
fi

grep "Backup-ZIP 1.0.12" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
    # change version data
    sed "s#Backup-ZIP 1.[0-9].[0-9]\{1,\}#Backup-ZIP 1.0.13#" "/etc/config.d/$prog" >/tmp/$prog-$$
    mv /tmp/$prog-$$ /etc/config.d/$prog

    sed "s#Update:  [0-9]*.[0-9]*.[0-9]*#Update:  22.10.2007#" "/etc/config.d/$prog" >/tmp/$prog-$$
    mv /tmp/$prog-$$ /etc/config.d/$prog
fi

grep "Backup-ZIP 1.0.13" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
    # backup Mount data
    {
    grep "BACKUP_MOUNT_N" /etc/config.d/$prog
    echo
    grep "BACKUP_MOUNT_[0-9]" /etc/config.d/$prog
    } >/tmp/mountdata

    # backup medium data
    {
    grep "BACKUP_MEDIUM" /etc/config.d/$prog
    } >/tmp/mediumdata

    # backup mail data
    {
    grep "BACKUP_INFO" /etc/config.d/$prog
    } >/tmp/maildata

    # backup Cron data
    {
    grep "BACKUP_CRON" /etc/config.d/$prog
    echo
    grep "BACKUP_PRE" /etc/config.d/$prog
    grep "BACKUP_POST" /etc/config.d/$prog
    } >/tmp/crondata

    # backup backup data
    {
    grep "BACKUP_N" /etc/config.d/$prog
    echo
    grep "BACKUP_[1-9]\{1,2\}" /etc/config.d/$prog
    } >/tmp/backupdata
    {
    grep "BACKUP_N" /tmp/backupdata
    idx=`grep "BACKUP_N" /tmp/backupdata | cut -d "'" -f 2`
    nr=1
    while [ "$nr" -le "$idx" ] ; do
        echo
        grep "BACKUP_"$nr"_CRON_JOB" /tmp/backupdata
        grep "BACKUP_"$nr"_PRE_EXEC" /tmp/backupdata
        grep "BACKUP_"$nr"_POST_EXEC" /tmp/backupdata
        grep "BACKUP_"$nr"_TEC" /tmp/backupdata
        echo "BACKUP_"$nr"_TEC_RSYN='-a --delete'          # only for rsyn, e.g. \"-a --delete\""
        echo "BACKUP_"$nr"_TEC_RSYN_SSHP='22'              # only for rsync/ssh, SSH-Port, e.g. 22"
        grep "BACKUP_"$nr"_SIZE" /tmp/backupdata
        grep "BACKUP_"$nr"_ROTATION" /tmp/backupdata
        grep "BACKUP_"$nr"_SOURCE" /tmp/backupdata
        grep "BACKUP_"$nr"_TARGET" /tmp/backupdata
        nr=`expr $nr + 1`
    done
    } >>/tmp/backupdata-$$
    mv /tmp/backupdata-$$ /tmp/backupdata
    # transform
    sed 's#SIZE#TEC_SIZE#g' </tmp/backupdata >/tmp/$prog-$$
    mv /tmp/$prog-$$ /tmp/backupdata
    sed 's#splitsize (MB), please read Docu#only for gzip|bzip2|none|rar, splitsize in MB#g' </tmp/backupdata >/tmp/$prog-$$
    mv /tmp/$prog-$$ /tmp/backupdata

    # create new Config
    {
    echo "#! /bin/sh"
    echo "#----------------------------------------------------------------------------"
    echo "# /usr/local/backup/backup.create"
    echo "#"
    echo "# --- Backup-ZIP 1.0.15 for Eis/Fair Server ---"
    echo "#"
    echo "# Copyright (c) 2005 Hans-Peter Seiler <hanspeterseiler(at)web.de>"
    echo "#"
    echo "# Creation:     15.09.2005  hs"
    echo "# Last Update:  12.03.2009  hs"
    echo "#"
    echo "# This program is free software; you can redistribute it and/or modify"
    echo "# it under the terms of the GNU General Public License as published by"
    echo "# the Free Software Foundation; either version 2 of the License, or"
    echo "# (at your option) any later version."
    echo "#----------------------------------------------------------------------------"
    echo
    echo "#----------------------------------------------------------------------------"
    echo "# Here you can mount Harddisks or Samba Shares for your Backups"
    echo "#----------------------------------------------------------------------------"
    echo
    cat "/tmp/mountdata"
    echo
    echo "#----------------------------------------------------------------------------"
    echo "# Create Rescue Medium"
    echo "# This automatically stores your Configs, Users and the hole Programm to"
    echo "# a Floppy Disk or USB-Stick (read Doku)."
    echo "#----------------------------------------------------------------------------"
    echo
    cat "/tmp/mediumdata"
    echo
    echo "#----------------------------------------------------------------------------"
    echo "# Send Log via Mail after Backups"
    echo "#----------------------------------------------------------------------------"
    echo
    cat "/tmp/maildata"
    echo
    echo "#----------------------------------------------------------------------------"
    echo "# Backup Jobs"
    echo "# Don't change TEC after Backup-Job!!!"
    echo "#----------------------------------------------------------------------------"
    echo
    cat "/tmp/crondata"
    echo
    cat "/tmp/backupdata"
    echo
    echo "#----------------------------------------------------------------------------"
    echo "# End"
    echo "#----------------------------------------------------------------------------"
    } >/etc/config.d/$prog-$$
    mv /etc/config.d/$prog-$$ /etc/config.d/$prog
    rm -f /tmp/mountdata /tmp/mediumdata /tmp/maildata /tmp/crondata /tmp/backupdata
fi

grep "Backup-ZIP 1.0.15" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
    # change version data
    sed "s#Backup-ZIP 1.[0-9].[0-9]\{1,\}#Backup-ZIP 1.0.16#" "/etc/config.d/$prog" >/tmp/$prog-$$
    mv /tmp/$prog-$$ /etc/config.d/$prog

    sed "s#Update:  [0-9]*.[0-9]*.[0-9]*#Update:  04.04.2009#" "/etc/config.d/$prog" >/tmp/$prog-$$
    mv /tmp/$prog-$$ /etc/config.d/$prog

    sed 's/# usb, floppy/# usb|floppy|drive/g' "/etc/config.d/$prog" >/tmp/$prog-$$
    mv /tmp/$prog-$$ /etc/config.d/$prog
fi

grep "Backup-ZIP 1.0.16" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
  # change version data
  sed "s#Backup-ZIP 1.[0-9].[0-9]\{1,\}#Backup-ZIP 1.0.40#" "/etc/config.d/$prog" >/tmp/$prog-$$
  mv /tmp/$prog-$$ /etc/config.d/$prog
  _IFS=$IFS
  IFS=''
  while IFS='' read line ; do
    if ( echo ${line} | grep -q "#! /bin/sh" ) ; then
      >> /tmp/$prog-$$
    else
      if ( echo ${line} | grep -q "backup.create" ) ; then
        echo "# /etc/config.d/backup-zip - backup-zip configuration file" >> /tmp/$prog-$$
      else
        if ( echo ${line} | grep -q ^"# Copyright (c) 2005 " ) ; then
          echo "${line}" >> /tmp/$prog-$$
          echo "#               2015 Marcus Roeckrath <marcus.roeckrath(at)gmx.de>" >> /tmp/$prog-$$
        else
          if ( echo ${line} | grep -q ^"# Last Update:" ) ; then
            echo "# Last Update:  02.08.2015  mr" >> /tmp/$prog-$$
          else
            if ( echo ${line} | grep -q "usb_ext3|" ) ; then
              echo "${line}" | sed 's/usb_ext3|/usb_ext3|usb_ext4|/g' >> /tmp/$prog-$$
            else
              if ( echo ${line} | grep -q "BACKUP_MOUNT_" ) && ( echo ${line} | grep -q "_DRV='" ) ; then
                nr=`echo ${line} | cut -d "_" -f 3`
                if [ $nr == 1 ] ; then
                  echo "BACKUP_MOUNT_"$nr"_OPTIONS=''              # mount options f. e. iocharset=utf8; comma separated" >> /tmp/$prog-$$
                else
                  echo "BACKUP_MOUNT_"$nr"_OPTIONS=''" >> /tmp/$prog-$$
                fi
              else
                if ( echo ${line} | grep -q "BACKUP_MEDIUM_CRON_USE=" ) ; then
                  echo "BACKUP_MEDIUM_MOUNT_OPTIONS=''         # vfat mount options f. e. utf8; comma separated" >> /tmp/$prog-$$
                fi
              fi
              echo "${line}" >> /tmp/$prog-$$
            fi
          fi
        fi
      fi
    fi
  done < /etc/config.d/$prog
  IFS=$_IFS
  mv /tmp/$prog-$$ /etc/config.d/$prog
fi

grep "Backup-ZIP 1.0.40" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
  # change version data
  sed "s#Backup-ZIP 1.[0-9].[0-9]\{1,\}#Backup-ZIP 1.0.60#" "/etc/config.d/$prog" >/tmp/$prog-$$
  mv /tmp/$prog-$$ /etc/config.d/$prog
  _IFS=$IFS
  IFS=''
  while IFS='' read line ; do
    if ( echo ${line} | grep -q ^"# /usr/local/backup/backup.create" ) ; then
      echo "# /etc/config.d/backup-zip - backup-zip configuration file" >> /tmp/$prog-$$
    else
      if ( echo ${line} | grep -Eq "^#[[:space:]]*2015 Marcus Roeckrath " ) ; then
        echo "#               2015-2017 Marcus Roeckrath <marcus.roeckrath(at)gmx.de>" >> /tmp/$prog-$$
      else
        if ( echo ${line} | grep -q ^"# Last Update:" ) ; then
          echo "# Last Update:  26.10.2017  mr" >> /tmp/$prog-$$
        else
          echo ${line} >> /tmp/$prog-$$
        fi
      fi
    fi
  done < /etc/config.d/$prog
  IFS=$_IFS
  mv /tmp/$prog-$$ /etc/config.d/$prog
fi

grep "Backup-ZIP 1.0.60" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
  # change version data
  sed "s#Backup-ZIP 1.[0-9].[0-9]\{1,\}#Backup-ZIP 1.2.2#" "/etc/config.d/$prog" >/tmp/$prog-$$
  mv /tmp/$prog-$$ /etc/config.d/$prog
  _IFS=$IFS
  IFS=''
  while IFS='' read line ; do
    if ( echo ${line} | grep -Eq "^#[[:space:]]*2015-2017 Marcus Roeckrath " ) ; then
      echo "#               2015-2018 Marcus Roeckrath <marcus.roeckrath(at)gmx.de>" >> /tmp/$prog-$$
    else
      if ( echo ${line} | grep -q ^"# Last Update:" ) ; then
          echo "# Last Update:  03.02.2018  mr" >> /tmp/$prog-$$
      else
        if ( echo ${line} | grep -q "BACKUP_MEDIUM=" ) ; then
          echo "# Functionality removed completely!" >> /tmp/$prog-$$
        else
          echo ${line} | grep -v "BACKUP_MEDIUM_" >> /tmp/$prog-$$
        fi
      fi
    fi
  done < /etc/config.d/$prog
  IFS=$_IFS
  mv /tmp/$prog-$$ /etc/config.d/$prog
fi

grep "Backup-ZIP 1.2.2" /etc/config.d/$prog >/dev/null 2>&1
if [ "$?" = "0" ] ; then
  # change version data
  sed "s#Backup-ZIP 1.[0-9].[0-9]\{1,\}#Backup-ZIP 1.5.0#" "/etc/config.d/$prog" >/tmp/$prog-$$
  mv /tmp/$prog-$$ /etc/config.d/$prog
  _IFS=$IFS
  IFS=''
  while IFS='' read line ; do
    if ( echo ${line} | grep -Eq "^#[[:space:]]*2015-2018 Marcus Roeckrath " ) ; then
      echo "#               2015-2021 Marcus Roeckrath <marcus.roeckrath(at)gmx(dot)de>" >> /tmp/$prog-$$
    else
      if ( echo ${line} | grep -q ^"# Last Update:" ) ; then
          echo "# Last Update:  28.01.2021  mr" >> /tmp/$prog-$$
      else
        if ( echo ${line} | grep -q "usb_ext3|" ) ; then
          echo "${line}" | sed -e 's/usb_vfat|/usb_vfat|usb_f2fs|/g' -e 's/|vfat/|vfat|f2fs/g' >> /tmp/$prog-$$
        else
          echo "${line}" >> /tmp/$prog-$$
        fi
      fi
    fi
  done < /etc/config.d/$prog
  IFS=$_IFS
  mv /tmp/$prog-$$ /etc/config.d/$prog
fi
